#ifndef FLYNOTIFYCONFIG_PLAYER_H
#define FLYNOTIFYCONFIG_PLAYER_H

#include <QWidget>

#include <FlyNotifyConfig/Global>

namespace Fly {

namespace NotifyConfig {
class Element;
} // Fly::NotifyConfig

class NotifyConfigWidgetPrivate;

class FLYNOTIFYCONFIG_EXPORT NotifyConfigWidget : public QWidget
{
    Q_OBJECT

public:
    explicit NotifyConfigWidget(QWidget* parent = nullptr,
                                Qt::WindowFlags f = Qt::WindowFlags());
    ~NotifyConfigWidget() override;

    //!
    //! \brief Create NotifyConfigWidget by application name.
    //! \param parent - parent widget.
    //! \param appName - application name, need for file "*.notifyrc" identification.
    //! \return New NotifyConfigWidget object.
    //!
    static NotifyConfigWidget *configure(QWidget *parent = nullptr,
                                         const QString &appName = QString());

    //!
    //! \brief Load events by application name.
    //! \param appName - application name, need for file "*.notifyrc" identification.
    //! \param contextName - context name for eventId.
    //! \param contextValue - context value for eventId.
    //!
    void setApplication(const QString &appName = QString(),
                        const QString &contextName = QString(),
                        const QString &contextValue = QString());

    //!
    //! \brief Select event row by id.
    //! \param eventId - event identification.
    //!
    void selectEvent(const QString &eventId);

public slots:
    //!
    //! \brief Save all events changes.
    //!
    void save();

    //!
    //! \brief Revert all events settings to defaults.
    //!
    void revertToDefaults();

    //!
    //! \brief Disable sound for all events.
    //!
    void disableAllSounds();

signals:
    //!
    //! \brief Changed state.
    //! \param state - are there any changes.
    //!
    void changed(bool state);

private slots:
    void slotEventSelected(NotifyConfig::Element *element);
    void onActionChanged();

private:
    NotifyConfigWidgetPrivate *d;

    void init();
};

} // namespace Fly

#endif // FLYNOTIFYCONFIG_PLAYER_H
